const fs = require('fs')
const path = require('path')
const _ = require('lodash')
const postcss = require('postcss')
const functions = require('postcss-functions')
const imageSize = require('image-size')

module.exports = postcss.plugin('imager', function (options = {}) {
  function getImageSize(img) {
    const filePath = path.resolve(options.folder, img.slice(1, -1))
    if (!fs.existsSync(filePath)) return options.default
    return imageSize(filePath)
  }

  options = _.extend({
    default: {
      width: 0,
      height: 0,
    },
    converter: size => size + 'px',
  }, options)

  return postcss()
    .use(css => {
      options.folder = path.dirname(css.source.input.file)
    })
    .use(functions({
      functions: {
        width: (img, converter = options.converter) => {
          const info = getImageSize(img)
          return converter(info.width)
        },
        height: (img, converter = options.converter) => {
          const info = getImageSize(img)
          return converter(info.height)
        },
      }
    }))
})
